/*
 * iwconnect/netdevice.h
 * $Rev: 1222 $
 *
 * Copyright (C) 2008-2010, Reto Gantenbein <reto.gantenbein@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __NETDEV_H
#define __NETDEV_H

/**
 * @file netdevice.h
 * @brief Interface for network device handling
 */

/* INCLUDES *******************************************************************/

#include <netinet/in.h>         // struct in_addr, struct in6_addr
#include <netdb.h>              // struct addrinfo


/* CUSTOM NETWORK TYPES *******************************************************/

/** Storage for IPv4 or IPv6 address structures */
typedef union {
    struct in_addr     v4addr;  /**< IPv4 IP address structure */
    struct in6_addr    v6addr;  /**< IPv6 IP address structure */
} addr_storage;


/* NETWORK DEVICE RELATED PUBLIC FUNCTIONS ************************************/

int
init_udp_socket();

int
get_mac_by_dev(unsigned char *, const char *);

int
get_ip_by_dev(addr_storage *, const char *);

int
get_mtu_by_dev(const char *);

int
bind_net_socket(const struct addrinfo *addr);

int
open_tap_socket(const char *);

#endif
