/*
 * wlanmodel/ProtocolHandler.h
 *
 * Copyright (C) 2008-2010 Reto Gantenbein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#ifndef PROTOCOLHANDLER_H
#define PROTOCOLHANDLER_H

#include <omnetpp.h>
#include "EmulationRTScheduler.h"
#include "NodeManager.h"
#include "PMTypes.h"
#include "VifBackend.h"

/**
 * Class responsible to distribute packets to simulated hosts representations
 */
class ProtocolHandler : public cSimpleModule
{
    private:
        cMessage *rtEvent;
        EmulationRTScheduler *rtScheduler;
        NodeManager *nodeManager;
        cOutVector pktProcTime;

        //buffer
        char inBuffer[DATA_MSG_SIZE];
        int numRecvBytes;

    protected:
        virtual void initialize();

        //message processing
        virtual void handleMessage(cMessage *msg);
        void processRegistrationMsg(registrationMsg *msg);
        void processDeregistrationMsg(plainMsg *msg);
        void processDataMsg(dataMsg *msg);
        void processConfigurationMsg(configMsg *msg);

    public:
        ProtocolHandler();
        virtual ~ProtocolHandler();
        static uint8_t getMessageType(msgHeader *header);

        static void debugMessage(const char *, int);
        static void printConfigMessage(const char *);
        static void printRegisterMessage(const char *);
        static void printPlainMessage(const char *);
        static void printDataMessage(const char *);
};

#endif  // PROTOCOLHANDLER_H
